{% load i18n %}
<!DOCTYPE html>
<html lang="en">
	<head>
		<meta charset="UTF-8">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
		<script src="//ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
		<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
	{% block head_script %}
		<style>
			body{
				font-size: 14px;
			}
		</style>

		<script>
			function getCookie(name) {
				let cookieValue = null;
				if (document.cookie && document.cookie !== '') {
					const cookies = document.cookie.split(';');
					for (let i = 0; i < cookies.length; i++) {
						const cookie = cookies[i].trim();
						// Does this cookie string begin with the name we want?
						if (cookie.substring(0, name.length + 1) === (name + '=')) {
							cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
							break;
						}
					}
				}
				return cookieValue;
			}
		</script>
	{% endblock %}
	</head>
	<title>{{ title }}</title>
	<body>
		<div class="container">
			{% block header_block %}
				<h2 class="text-center mb-5 mt-3">
					<a href="{% url 'error_tracker:view_errors' %}" class="text-dark home-link">{% trans 'Errors Seen' %}</a>
				</h2>
			{% endblock %}
			{% block content_block %}
			{% endblock %}
		</div>
	</body>
</html>