# Generated by Django 3.1.2 on 2020-10-18 11:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('error_tracker', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='errormodel',
            name='notification_sent',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='errormodel',
            name='ticket_raised',
            field=models.BooleanField(default=False),
        ),
    ]